<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>AppearanceWidget</name>
    <message>
        <location filename="../PAppearanceWidget.ui" line="14"/>
        <source>Appearance</source>
        <translation>Uiterlijk</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="25"/>
        <source>PageEdit</source>
        <translation>PageEdit</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="31"/>
        <location filename="../PAppearanceWidget.ui" line="263"/>
        <source>Fonts:</source>
        <translation>Lettertypen:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="40"/>
        <source>If no font is specified in the CSS for your page, the following font will be used to display within PageEdit. These fonts will not be used in your actual ebook.</source>
        <translation>Als in de CSS voor uw pagina geen lettertype is opgegeven, zal het volgende lettertype worden gebruikt voor de weergave binnen PageEdit. Deze lettertypen zullen niet worden gebruikt in uw huidig e-boek.</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="70"/>
        <source>Default font size to be used for PageEdit
if no font-size specified in your CSS</source>
        <translation>Standaard tekengrootte die PageEdit gebruikt
als in de CSS geen tekengrootte is opgegeven</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="74"/>
        <location filename="../PAppearanceWidget.ui" line="323"/>
        <source>Font Size:</source>
        <translation>Lettergrootte:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="81"/>
        <source>Default font family to be used for PageEdit
if no font-family specified in your CSS</source>
        <translation>Standaard lettertypefamilie die PageEdit gebruikt
als in de CSS geen lettertypefamilie is opgegeven</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="85"/>
        <source>Standard:</source>
        <translation>Standaard:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="108"/>
        <source>Default font family to be used for PageEdit
if a serif font-family specified in your CSS</source>
        <translation>Standaard lettertypefamilie die PageEdit gebruikt
als in de CSS een lettertypefamilie met schreef is opgegeven</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="112"/>
        <source>Serif:</source>
        <translation>Met schreef:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="125"/>
        <source>Default font family to be used for PageEdit
if a sans-serif font-family specified in your CSS</source>
        <translation>Standaard lettertypefamilie die PageEdit gebruikt
als in de CSS een schreefloze lettertypefamilie is opgegeven</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="129"/>
        <source>Sans-Serif:</source>
        <translation>Schreefloos:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="156"/>
        <source>Make PageEdit simulate a dark appearance in dark mode</source>
        <translation>In donkere modus een donker uiterlijk tonen in PageEdit</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="181"/>
        <source>Main UI</source>
        <translation>Hoofdgebruikersinterface</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="187"/>
        <source>Main Menu Icon Size:</source>
        <translation>Formaat van pictogrammen in hoofdmenu:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="193"/>
        <source>Adjust the size of the icons in the main menu.</source>
        <translation>Aanpassen van het formaat van pictogrammen in het hoofdmenu.</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="231"/>
        <source>High DPI Setting:</source>
        <translation>Hoge DPI-instellingen:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="240"/>
        <source>(Needs PageEdit Restart)</source>
        <translation>(Vereist opnieuw starten van PageEdit)</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="269"/>
        <source>UI Font:</source>
        <translation>Lettertype gebruikersinterface:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="279"/>
        <source>Change the font used by PageEdit&apos;s menus, buttons, etc...</source>
        <translation>Het lettertype wijzigen dat door PageEdit wordt gebruikt voor menu&apos;s, knoppen en dergelijke</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="282"/>
        <source>Change Font (Needs PageEdit Restart)</source>
        <translation>Lettertype wijzigen (vereist opnieuw starten PageEdit)</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="306"/>
        <source>Insert Special Characters:</source>
        <translation>Speciale tekens invoegen:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="320"/>
        <source>Font size to be used for Insert Special Characters window</source>
        <translation>Lettergrootte die gebruikt wordt in het scherm Speciaal teken invoegen</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="353"/>
        <source>Font family to be used for Insert Special Characters window</source>
        <translation>Letterfamilie die wordt gebruikt in het scherm Speciaal teken invoegen</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="356"/>
        <source>Standard Font:</source>
        <translation>Standaardlettertype:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="423"/>
        <source>Reset all fonts and colors to the default values</source>
        <translation>Alle lettertypen en kleuren terugzetten naar de standaardwaarden.</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="426"/>
        <source>Reset All</source>
        <translation>Alles terugzetten</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="49"/>
        <location filename="../AppearanceWidget.cpp" line="50"/>
        <source>Detect</source>
        <translation>Autodetectie</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="49"/>
        <location filename="../AppearanceWidget.cpp" line="52"/>
        <source>On</source>
        <translation>Aan</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="49"/>
        <location filename="../AppearanceWidget.cpp" line="54"/>
        <source>Off</source>
        <translation>Uit</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="50"/>
        <source>Detect whether any high dpi scaling should take place.</source>
        <translation>Detecteren of DPI-schaalbaarheid moet worden toegepast.</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="51"/>
        <source>Defers to any Qt environment variables that are set to control high dpi behavior.</source>
        <translation>Overlaten aan de Qt-omgevingsvariabelen voor het regelen van het gedrag bij hoge DPI. </translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="52"/>
        <source>Turns on high dpi scaling and ignores any Qt environment variables</source>
        <translation>Schakelt DPI-schaalbaarheid in en negeert de Qt-omgevingsvariabelen.</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="53"/>
        <source>that are set controlling high dpi behavior.</source>
        <translation>voor het regelen van het gedrag bij hoge DPI.</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="54"/>
        <source>Turns off high dpi scaling regardless if any Qt environment</source>
        <translation>Schakelt DPI-schaalbaarheid uit ongeacht de Qt-omgevingsvariabelen</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="55"/>
        <source>variables controlling high dpi behavior are set.</source>
        <translation>voor het regelen van het gedrag bij hoge DPI.</translation>
    </message>
</context>
<context>
    <name>GeneralSettings</name>
    <message>
        <location filename="../PGeneralSettings.ui" line="14"/>
        <source>General Settings</source>
        <translation>Algemene instellingen</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="37"/>
        <source>You must restart PageEdit after changing the User Interface language.

If a translation for specific word or phrase is not available it will be displayed in English.</source>
        <translation>Na het veranderen van de taal van de gebruikersinterface moet PageEdit opnieuw worden opgestart.

Als er voor een bepaald woord of uitdrukking geen vertaling beschikbaar is, dan wordt deze getoond in het Engels.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="42"/>
        <source>User Interface Language:</source>
        <translation>Taal van gebruikersinterface:</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="74"/>
        <source>Select from installed spellcheck dictionaries.</source>
        <translation>Selecteren uit geïnstalleerde woordenlijsten voor spellingcontrole.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="77"/>
        <source>Spellcheck Dictionary:</source>
        <translation>Woordenlijst spellingcontrole:</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="119"/>
        <source>Determine if html files are allowed to access non-multimedia remote resources.</source>
        <translation>Bepalen of html-bestanden toegang mogen hebben tot niet-multimediale externe bronnen.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="122"/>
        <source> Control access by html files to non-multimedia remote resources.</source>
        <translation>Instellen of html-bestanden toegang mogen hebben tot niet-multimediale externe bronnen.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="131"/>
        <source>Check to allow html files to access non-multimedia remote resources.</source>
        <translation>Aanvinken om html-bestanden toe te staan niet-multimediale externe bronnen te benaderen.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="134"/>
        <source>Html files may access all remote resources types.</source>
        <translation>Html-bestanden mogen alle externe bronnen benaderen.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="161"/>
        <source>Determine if javascript is allowed to be used by html files</source>
        <translation>Bepalen of html-bestanden javascript mogen gebruiken.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="164"/>
        <source> Control use of javascript by html files.</source>
        <translation>Instellen of html-bestanden javascript mogen gebruiken.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="173"/>
        <source>Check to allow html files to use javascript.</source>
        <translation>Aanvinken om html-bestanden toe te staan javascript te gebruiken.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="176"/>
        <source>Html files may use javascript.</source>
        <translation>Html-bestanden mogen javascript gebruiken.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="204"/>
        <source>Choose how you would like PageEdit to handle the use of multiple white space characters during editing.</source>
        <translation>Kiezen hoe u wilt dat PageEdit bij het bewerken omgaat met meerdere spaties achter elkaar.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="207"/>
        <source>Handle multiple white space layout using:</source>
        <translation>Omgaan met meerdere spaties achter elkaar via: </translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="213"/>
        <source>Use CSS white-space: pre-wrap</source>
        <translation>Gebruik maken van CSS white-space: pre-wrap</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="216"/>
        <source>css white-space: pre-wrap</source>
        <translation>CSS white space: pre-wrap</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="226"/>
        <source>Use non-breaking spaces as needed</source>
        <translation>Indien nodig vaste spaties gebruiken</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="229"/>
        <source>non-breaking spaces as needed</source>
        <translation>vaste spaties indien nodig</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="257"/>
        <source>Determine if Prettify is used when saving</source>
        <translation>Bepalen of xhtml-code wordt opgemaakt bij het opslaan</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="260"/>
        <source> Use Prettify to reformat the xhtml when saving.</source>
        <translation>Xhtml-code opmaken bij het opslaan.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="269"/>
        <source>Check to reformat with Prettify when saving xhtml files.</source>
        <translation>Aanvinken om xhtml-code op te maken bij het opslaan.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="272"/>
        <source>Use Prettify to reformat xhtml when saving.</source>
        <translation>Xhtml-code opmaken bij het opslaan.</translation>
    </message>
</context>
<context>
    <name>Inspector</name>
    <message>
        <location filename="../Inspector.cpp" line="74"/>
        <source>Inspect Page or Element</source>
        <translation>Pagina of element onderzoeken</translation>
    </message>
    <message>
        <location filename="../Inspector.cpp" line="156"/>
        <source>The Inspector functionality is not supported before Qt 5.11</source>
        <translation>De onderzoeksfunctionaliteit is alleen beschikbaar vanaf Qt 5.11</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main.ui" line="15"/>
        <location filename="../MainWindow.cpp" line="1012"/>
        <location filename="../MainWindow.cpp" line="1073"/>
        <location filename="../MainWindow.cpp" line="1764"/>
        <location filename="../MainWindow.cpp" line="1777"/>
        <location filename="../MainWindow.cpp" line="1783"/>
        <location filename="../MainWindow.cpp" line="1797"/>
        <location filename="../MainWindow.cpp" line="1810"/>
        <location filename="../MainWindow.cpp" line="1818"/>
        <location filename="../MainWindow.cpp" line="1873"/>
        <location filename="../MainWindow.cpp" line="1960"/>
        <source>PageEdit</source>
        <translation>PageEdit</translation>
    </message>
    <message>
        <location filename="../main.ui" line="62"/>
        <source>&amp;File</source>
        <translation>&amp;Bestand</translation>
    </message>
    <message>
        <location filename="../main.ui" line="75"/>
        <source>&amp;Edit</source>
        <translation>Be&amp;werken</translation>
    </message>
    <message>
        <location filename="../main.ui" line="88"/>
        <source>&amp;Find</source>
        <translation>&amp;Zoeken</translation>
    </message>
    <message>
        <location filename="../main.ui" line="95"/>
        <source>&amp;Insert</source>
        <translation>&amp;Invoegen</translation>
    </message>
    <message>
        <location filename="../main.ui" line="110"/>
        <source>For&amp;mat</source>
        <translation>&amp;Opmaak</translation>
    </message>
    <message>
        <location filename="../main.ui" line="115"/>
        <source>&amp;Heading</source>
        <translation>&amp;Alinea</translation>
    </message>
    <message>
        <location filename="../main.ui" line="130"/>
        <source>C&amp;hange Case</source>
        <translation>Omzetten hoofd- en kleine &amp;letters</translation>
    </message>
    <message>
        <location filename="../main.ui" line="160"/>
        <source>&amp;View</source>
        <translation>Beel&amp;d</translation>
    </message>
    <message>
        <location filename="../main.ui" line="169"/>
        <source>Inspector</source>
        <translation>Onderzoeken</translation>
    </message>
    <message>
        <location filename="../main.ui" line="185"/>
        <source>File</source>
        <translation>Bestand</translation>
    </message>
    <message>
        <location filename="../main.ui" line="199"/>
        <source>Edit</source>
        <translation>Bewerken</translation>
    </message>
    <message>
        <location filename="../main.ui" line="217"/>
        <location filename="../main.ui" line="1157"/>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <location filename="../main.ui" line="230"/>
        <source>Insert</source>
        <translation>Invoegen</translation>
    </message>
    <message>
        <location filename="../main.ui" line="249"/>
        <source>Inspect</source>
        <translation>Onderzoeken</translation>
    </message>
    <message>
        <location filename="../main.ui" line="262"/>
        <location filename="../main.ui" line="1106"/>
        <source>Find</source>
        <translation>Zoeken</translation>
    </message>
    <message>
        <location filename="../main.ui" line="275"/>
        <source>Heading</source>
        <translation>Koptekst</translation>
    </message>
    <message>
        <location filename="../main.ui" line="289"/>
        <source>set Heading Level of Selected Text</source>
        <translation>Kopniveau van geselecteerde tekst instellen</translation>
    </message>
    <message>
        <location filename="../main.ui" line="303"/>
        <source>Change Case</source>
        <translation>Hoofdletter wijzigen</translation>
    </message>
    <message>
        <location filename="../main.ui" line="319"/>
        <source>Format</source>
        <translation>Formaat</translation>
    </message>
    <message>
        <location filename="../main.ui" line="337"/>
        <source>Align</source>
        <translation>Uitlijnen</translation>
    </message>
    <message>
        <location filename="../main.ui" line="353"/>
        <source>Indent</source>
        <translation>Inspringen</translation>
    </message>
    <message>
        <location filename="../main.ui" line="367"/>
        <source>Navigate</source>
        <translation>Navigeren</translation>
    </message>
    <message>
        <location filename="../main.ui" line="377"/>
        <source>Navigation List</source>
        <translation>Navigatielijst</translation>
    </message>
    <message>
        <location filename="../main.ui" line="393"/>
        <source>&amp;Save</source>
        <translation>O&amp;pslaan</translation>
    </message>
    <message>
        <location filename="../main.ui" line="396"/>
        <source>Save the current file.</source>
        <translation>Het huidige bestand opslaan.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="399"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../main.ui" line="409"/>
        <source>&amp;Print</source>
        <translation>Af&amp;drukken</translation>
    </message>
    <message>
        <location filename="../main.ui" line="412"/>
        <source>Print the current Page.</source>
        <translation>De huidige pagina afdrukken.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="415"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../main.ui" line="421"/>
        <source>Save &amp;As...</source>
        <translation>Opslaan a&amp;ls...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="424"/>
        <source>Save the current file with a different filename.</source>
        <translation>Het huidige bestand opslaan onder een andere bestandsnaam.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="427"/>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <location filename="../main.ui" line="437"/>
        <source>Cu&amp;t</source>
        <translation>K&amp;nippen</translation>
    </message>
    <message>
        <location filename="../main.ui" line="440"/>
        <source>Cuts the selected text from the document and puts it on the clipboard.</source>
        <translation>De in het document geselecteerde tekst knippen en op het klembord plaatsen.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="450"/>
        <source>&amp;Paste</source>
        <translation>&amp;Plakken</translation>
    </message>
    <message>
        <location filename="../main.ui" line="453"/>
        <source>Pastes the content from the clipboard into the file.</source>
        <translation>De inhoud van het klembord in het bestand plakken.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="463"/>
        <source>&amp;Undo</source>
        <translation>&amp;Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../main.ui" line="466"/>
        <source>Reverts the changes of the previous operation.</source>
        <translation>De wijzigingen van de voorgaande bewerking ongedaan maken.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="469"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../main.ui" line="479"/>
        <source>&amp;Redo</source>
        <translation>Opnieuw &amp;uitvoeren</translation>
    </message>
    <message>
        <location filename="../main.ui" line="482"/>
        <source>Restores the changes reverted by the previous Undo action.</source>
        <translation>Terugdraaien van de laatste actie waarbij een bewerking ongedaan is gemaakt.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="485"/>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <location filename="../main.ui" line="495"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopiëren</translation>
    </message>
    <message>
        <location filename="../main.ui" line="498"/>
        <source>Copies the selected text and puts it on the clipboard.</source>
        <translation>De geselecteerde tekst kopiëren en op het klembord plaatsen.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="511"/>
        <source>Align &amp;Left</source>
        <translation>&amp;Links uitlijnen</translation>
    </message>
    <message>
        <location filename="../main.ui" line="514"/>
        <source>Align the paragraph to the left.</source>
        <translation>De alinea links uitlijnen.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="528"/>
        <source>Align &amp;Right</source>
        <translation>&amp;Rechts uitlijnen</translation>
    </message>
    <message>
        <location filename="../main.ui" line="531"/>
        <source>Align the paragraph to the right.</source>
        <translation>De alinea rechts uitlijnen.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="544"/>
        <source>&amp;Center</source>
        <translation>&amp;Centreren</translation>
    </message>
    <message>
        <location filename="../main.ui" line="547"/>
        <source>Center the paragraph.</source>
        <translation>De alinea centreren.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="550"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../main.ui" line="563"/>
        <source>&amp;Justify</source>
        <translation>&amp;Uitvullen</translation>
    </message>
    <message>
        <location filename="../main.ui" line="566"/>
        <source>Align the paragraph to both the left and right margins.</source>
        <translation>Tekst uitlijnen op zowel de linker- als rechtermarge.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="569"/>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <location filename="../main.ui" line="582"/>
        <source>&amp;Bold</source>
        <translation>&amp;Vet</translation>
    </message>
    <message>
        <location filename="../main.ui" line="585"/>
        <source>Make the selected text bold.</source>
        <translation>De geselecteerde tekst vet maken.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="588"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../main.ui" line="601"/>
        <source>&amp;Italic</source>
        <translation>Curs&amp;ief</translation>
    </message>
    <message>
        <location filename="../main.ui" line="604"/>
        <source>Make the selected text italic.</source>
        <translation>De geselecteerde tekst cursief maken.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="607"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../main.ui" line="617"/>
        <source>&amp;Open...</source>
        <translation>&amp;Openen...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="620"/>
        <source>Open a file from disk.</source>
        <translation>Een bestand van schijf openen.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="623"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../main.ui" line="636"/>
        <source>&amp;Underline</source>
        <translation>&amp;Onderstrepen</translation>
    </message>
    <message>
        <location filename="../main.ui" line="639"/>
        <source>Underline the selected text.</source>
        <translation>De geselecteerde tekst onderstrepen.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="642"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../main.ui" line="652"/>
        <source>&amp;Lowercase</source>
        <translation>&amp;Kleine letters</translation>
    </message>
    <message>
        <location filename="../main.ui" line="655"/>
        <source>Set selected text to lowercase.</source>
        <translation>De geselecteerde tekst wijzigen in kleine letters.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="658"/>
        <source>Alt+L</source>
        <translation>Alt+L</translation>
    </message>
    <message>
        <location filename="../main.ui" line="668"/>
        <source>&amp;Uppercase</source>
        <translation>&amp;Hoofdletters</translation>
    </message>
    <message>
        <location filename="../main.ui" line="671"/>
        <source>Set selected text to uppercase.</source>
        <translation>De geselecteerde tekst wijzigen in hoofdletters.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="674"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../main.ui" line="684"/>
        <source>&amp;Titlecase</source>
        <translation>Eerste letter &amp;woord hoofdletter</translation>
    </message>
    <message>
        <location filename="../main.ui" line="687"/>
        <source>Capitalize the first letter of each word selected.</source>
        <translation>De eerste letter van elk geselecteerd woord wijzigen in een hoofdletter.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="697"/>
        <source>&amp;Capitalize</source>
        <translation>&amp;Eerste letter hoofdletter</translation>
    </message>
    <message>
        <location filename="../main.ui" line="700"/>
        <source>Capitalize only the first word of the selected text.</source>
        <translation>Alleen de eerste letter van de geselecteerde tekst wijzigen in een hoofdletter.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="710"/>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <location filename="../main.ui" line="713"/>
        <source>Quit</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <location filename="../main.ui" line="716"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../main.ui" line="726"/>
        <source>&amp;Special Character...</source>
        <translation>&amp;Speciaal teken...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="729"/>
        <source>Select a character to insert into your text.</source>
        <translation>Een teken selecteren om in uw tekst in te voegen.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="742"/>
        <source>&amp;Numbered List</source>
        <translation>Ge&amp;nummerde lijst</translation>
    </message>
    <message>
        <location filename="../main.ui" line="745"/>
        <source>Create a numbered list from selection.</source>
        <translation>De geselecteerde tekst omzetten naar een genummerde lijst.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="758"/>
        <source>Bulle&amp;ted List</source>
        <translation>Lijst met opsom&amp;mingstekens</translation>
    </message>
    <message>
        <location filename="../main.ui" line="761"/>
        <source>Create a bulleted list from selection.</source>
        <translation>De geselecteerde tekst omzetten naar een lijst met opsommingstekens.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="764"/>
        <source>Ctrl+Shift+L</source>
        <translation>Ctrl+Shift+L</translation>
    </message>
    <message>
        <location filename="../main.ui" line="777"/>
        <source>Stri&amp;kethrough</source>
        <translation>&amp;Doorhalen</translation>
    </message>
    <message>
        <location filename="../main.ui" line="780"/>
        <source>Draw a line through the selected text.</source>
        <translation>Een streep trekken door het midden van de geselecteerde tekst.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="793"/>
        <source>&amp;Subscript</source>
        <translation>&amp;Subscript</translation>
    </message>
    <message>
        <location filename="../main.ui" line="796"/>
        <source>Set the selected text slightly smaller and below the normal line.</source>
        <translation>De geselecteerde tekst iets kleiner maken en onder de basislijn zetten.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="809"/>
        <source>Su&amp;perscript</source>
        <translation>Su&amp;perscript</translation>
    </message>
    <message>
        <location filename="../main.ui" line="812"/>
        <source>Set the selected text slightly smaller and above the normal line.</source>
        <translation>De geselecteerde tekst iets kleiner maken en boven de basislijn zetten.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="823"/>
        <source>Zoom &amp;In</source>
        <translation>&amp;Inzoomen</translation>
    </message>
    <message>
        <location filename="../main.ui" line="826"/>
        <source>Zoom In</source>
        <translation>Inzoomen</translation>
    </message>
    <message>
        <location filename="../main.ui" line="829"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../main.ui" line="840"/>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Uitzoomen</translation>
    </message>
    <message>
        <location filename="../main.ui" line="843"/>
        <source>Zoom Out</source>
        <translation>Uitzoomen</translation>
    </message>
    <message>
        <location filename="../main.ui" line="846"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../main.ui" line="857"/>
        <source>Incre&amp;ase Indent</source>
        <translation>Inspringing ver&amp;groten</translation>
    </message>
    <message>
        <location filename="../main.ui" line="860"/>
        <source>Increase the indent level of the paragraph.</source>
        <translation>Het inspringniveau van de alinea vergroten.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="863"/>
        <source>Ctrl+Alt+M</source>
        <translation>Ctrl+Alt+M</translation>
    </message>
    <message>
        <location filename="../main.ui" line="873"/>
        <source>&amp;Decrease Indent</source>
        <translation>Inspringing ver&amp;kleinen</translation>
    </message>
    <message>
        <location filename="../main.ui" line="876"/>
        <source>Decrease the indent level of the paragraph.</source>
        <translation>Het inspringniveau van de alinea verkleinen.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="879"/>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
    <message>
        <location filename="../main.ui" line="889"/>
        <source>Split &amp;Marker</source>
        <translation>Splits&amp;markering</translation>
    </message>
    <message>
        <location filename="../main.ui" line="892"/>
        <source>Insert Sigil split file marker</source>
        <translation>Sigil-markering invoegen voor het splitsen van een bestand</translation>
    </message>
    <message>
        <location filename="../main.ui" line="895"/>
        <source>Ctrl+Shift+Return</source>
        <translation>Ctrl+Shift+Return</translation>
    </message>
    <message>
        <location filename="../main.ui" line="901"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Voorkeuren...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="904"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../main.ui" line="910"/>
        <source>&amp;Zoom Reset</source>
        <translation>&amp;Zoom terugzetten</translation>
    </message>
    <message>
        <location filename="../main.ui" line="913"/>
        <source>Zoom Reset</source>
        <translation>Zoom terugzetten</translation>
    </message>
    <message>
        <location filename="../main.ui" line="916"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../main.ui" line="929"/>
        <source>Heading &amp;1</source>
        <translation>Kop &amp;1</translation>
    </message>
    <message>
        <location filename="../main.ui" line="932"/>
        <source>Format paragraph as a level 1 heading.</source>
        <translation>Alinea als kop 1 opmaken.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="935"/>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <location filename="../main.ui" line="948"/>
        <source>Heading &amp;2</source>
        <translation>Kop &amp;2</translation>
    </message>
    <message>
        <location filename="../main.ui" line="951"/>
        <source>Format paragraph as a level 2 heading.</source>
        <translation>Alinea als kop 2 opmaken.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="954"/>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <location filename="../main.ui" line="967"/>
        <source>Heading &amp;3</source>
        <translation>Kop &amp;3</translation>
    </message>
    <message>
        <location filename="../main.ui" line="970"/>
        <source>Format paragraph as a level 3 heading.</source>
        <translation>Alinea als kop 3 opmaken.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="973"/>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <location filename="../main.ui" line="987"/>
        <source>Heading &amp;4</source>
        <translation>Kop &amp;4</translation>
    </message>
    <message>
        <location filename="../main.ui" line="990"/>
        <source>Format paragraph as a level 4 heading.</source>
        <translation>Alinea als kop 4 opmaken.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="993"/>
        <source>Ctrl+4</source>
        <translation>Ctrl+4</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1006"/>
        <source>Heading &amp;5</source>
        <translation>Kop &amp;5</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1009"/>
        <source>Format paragraph as a level 5 heading.</source>
        <translation>Alinea als kop 5 opmaken.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1012"/>
        <source>Ctrl+5</source>
        <translation>Ctrl+5</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1025"/>
        <source>Heading &amp;6</source>
        <translation>Kop &amp;6</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1028"/>
        <source>Format paragraph as a level 6 heading.</source>
        <translation>Alinea als kop 6 opmaken.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1031"/>
        <source>Ctrl+6</source>
        <translation>Ctrl+6</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1045"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normaal</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1048"/>
        <source>ormat paragraph as a normal paragraph.</source>
        <translation>Alinea opmaken als een standaard alinea.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1051"/>
        <source>Ctrl+7</source>
        <translation>Ctrl+7</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1061"/>
        <source>&amp;Preserve Existing Attributes</source>
        <translation>&amp;Bestaande kopeigenschappen behouden</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1064"/>
        <source>When applying this style, preserve any existing attributes on the tag</source>
        <translation>Bij toepassing van deze stijl, alle bestaande eigenschappen op de tag behouden.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1074"/>
        <source>&amp;Select All</source>
        <translation>&amp;Alles selecteren</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1077"/>
        <source>Select all text in the document.</source>
        <translation>Alle tekst in het document selecteren.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1080"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1090"/>
        <source>&amp;Inspector</source>
        <translation>Onder&amp;zoeken</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1093"/>
        <source>Inspect the page.</source>
        <translation>De pagina onderzoeken.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1096"/>
        <source>Ctrl+F5</source>
        <translation>Ctrl+F5</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1109"/>
        <source>Find text in the page</source>
        <translation>Tekst zoeken op de pagina</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1112"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1125"/>
        <source>Next XHtml File</source>
        <translation>Volgend xhtml-bestand</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1128"/>
        <source>Next file in navigation list</source>
        <translation>Volgend bestand in de navigatielijst</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1141"/>
        <source>Previous XHtml File</source>
        <translation>Voorgaand xhtml-bestand</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1144"/>
        <source>Previous file in navigation list</source>
        <translation>Voorgaand bestand in de navigatielijst</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1160"/>
        <source>Toggle between Edit and Preview Modes.</source>
        <translation>Wisselen tussen Bewerkingsmodus en voorbeeldweergave.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1170"/>
        <source>About...</source>
        <translation>Over...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1173"/>
        <source>Show information about PageEdit.</source>
        <translation>Informatie tonen over PageEdit.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1183"/>
        <source>Back to Last Link</source>
        <translation>Terug naar de laatste koppeling</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1186"/>
        <source>Return from the last link taken</source>
        <translation>Terugkeren van de laatst uitgevoerde koppeling</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1196"/>
        <source>I&amp;D...</source>
        <translation>&amp;Referentie...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1199"/>
        <source>Insert or edit an anchor with an ID name to use as a link target.</source>
        <translation>Invoegen of bewerken van een anker met een identificerende naam om te gebruiken als koppelingsdoel.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1209"/>
        <source>&amp;Link...</source>
        <translation>Koppe&amp;ling...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1212"/>
        <source>Insert or edit an anchor with a hyperlink to a target.</source>
        <translation>Invoegen of bewerken van een anker met een hyperlink naar een doel.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1222"/>
        <source>&amp;File...</source>
        <translation>&amp;Bestand...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1225"/>
        <source>Select existing image, video or audio files from your book to insert into the text.</source>
        <translation>Selecteren van bestaande afbeeldings-, video- of audiobestanden van uw boek om in te voegen in de tekst.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1228"/>
        <source>Ctrl+Shift+I</source>
        <translation>Ctrl+Shift+I</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="750"/>
        <source>File load failed</source>
        <translation>Inlezen van bestand mislukt</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="751"/>
        <source>File Load Failed</source>
        <translation>Inlezen van bestand mislukt</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="846"/>
        <source>mode: Preview</source>
        <translation>modus: Voorbeeld</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="848"/>
        <source>mode: Edit</source>
        <translation>modus: Bewerken</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1012"/>
        <source>Are you sure you want to open this link in your browser?

%1</source>
        <translation>Weet u zeker dat u deze koppeling wilt openen in uw browser?

%1</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1074"/>
        <source>Do you want to save your changes before leaving?</source>
        <translation>Wilt u de wijzigingen opslaan voor het verlaten?</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1091"/>
        <source>PageEdit is closing...</source>
        <translation>PageEdit wordt afgesloten ...</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1223"/>
        <location filename="../MainWindow.cpp" line="1224"/>
        <location filename="../MainWindow.cpp" line="1225"/>
        <location filename="../MainWindow.cpp" line="1234"/>
        <location filename="../MainWindow.cpp" line="1235"/>
        <location filename="../MainWindow.cpp" line="1236"/>
        <source>HTML files (*.htm *.html *.xhtml)</source>
        <translation>HTML-bestanden (*.htm *.html *.xhtml)</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1226"/>
        <source>OPF files (*.opf)</source>
        <translation>OPF-bestanden (*.opf)</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1227"/>
        <source>All files (*.*)</source>
        <translation>Alle bestanden (*.*)</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1466"/>
        <source>Save File</source>
        <translation>Bestand opslaan</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1501"/>
        <location filename="../MainWindow.cpp" line="1502"/>
        <location filename="../MainWindow.cpp" line="1514"/>
        <location filename="../MainWindow.cpp" line="1515"/>
        <source>File Save-As Failed!</source>
        <translation>Opslaan van bestand als ... is mislukt!</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1501"/>
        <source>is not writeable</source>
        <translation>is alleen-lezen</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1510"/>
        <location filename="../MainWindow.cpp" line="1549"/>
        <source>File Saved</source>
        <translation>Bestand opgeslagen</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1540"/>
        <location filename="../MainWindow.cpp" line="1542"/>
        <location filename="../MainWindow.cpp" line="1553"/>
        <location filename="../MainWindow.cpp" line="1554"/>
        <source>File Save Failed!</source>
        <translation>Opslaan van bestand is mislukt!</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1541"/>
        <source>does not exist or is not writeable</source>
        <translation>bestaat niet of is alleen-lezen</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1570"/>
        <source>Do not show this warning again</source>
        <translation>Deze waarschuwing niet opnieuw weergeven</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1571"/>
        <source>This file may not print the way you expect it to.</source>
        <translation>Dit bestand wordt mogelijk niet afgedrukt zoals u verwacht.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1572"/>
        <source>Dark backgrounds and colored text applied with an EPUB&apos;s CSS will print.</source>
        <translation>Donkere achtergronden en gekleurde tekst die veroorzaakt zijn door de CSS van een epub worden ook zo afgedrukt. </translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1573"/>
        <source>Use caution as this can result in a lot of ink being used!</source>
        <translation>Wees voorzichtig, want dit kan leiden tot een hoog inktverbruik!</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1574"/>
        <source>Use the following Print Preview to see how this file will print.</source>
        <translation>Gebruik het volgende afdrukvoorbeeld om te zien hoe dit bestand wordt afgedrukt.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1575"/>
        <source>Check the box if you don&apos;t wish to see this warning in the future.</source>
        <translation>Schakel het selectievakje in als u deze waarschuwing voortaan niet meer wilt zien.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1598"/>
        <source>Feature not available before Qt5.12.x</source>
        <translation>Functie niet beschikbaar vóór Qt5.12.x</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1660"/>
        <source>File Opened</source>
        <translation>Bestand geopend</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1664"/>
        <source>File Open Failed!</source>
        <translation>Openen van bestand is mislukt!</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1687"/>
        <source>Clipboard contains HTML formatting</source>
        <translation>Klembord bevat HTML-opmaak</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1688"/>
        <source>Do you want to paste clipboard data as plain text?</source>
        <translation>Wilt u klembordgegevens plakken als platte tekst?</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1764"/>
        <source>You must select text before inserting a new id.</source>
        <translation>U dient tekst te selecteren voordat u een nieuwe referentie invoegt.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1777"/>
        <source>ID is invalid - must start with a letter, followed by letter number _ : - or .</source>
        <translation>Referentie is ongeldig.  Deze moet beginnen met een letter, gevolgd door letter, cijfer, laag streepje, dubbele punt, koppelteken of punt.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1783"/>
        <source>You cannot insert an id at this position.</source>
        <translation>Op deze positie kunt u geen referentie invoegen.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1797"/>
        <source>You must select text before inserting a new link.</source>
        <translation>U dient tekst te selecteren voordat u een nieuwe koppeling invoegt.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1810"/>
        <source>Link is invalid - cannot contain &apos;&lt;&apos; or &apos;&gt;&apos;</source>
        <translation>Koppeling is ongeldig - mag geen &quot;&lt;&quot; of &quot;&gt;&quot; bevatten</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1818"/>
        <source>You cannot insert a link at this position.</source>
        <translation>Op deze positie kunt u geen koppeling invoegen.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1829"/>
        <source>Insert File</source>
        <translation>Bestand invoegen</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1873"/>
        <source>You cannot insert a media file at this position.</source>
        <translation>Op deze positie kunt u geen mediabestand invoegen.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1961"/>
        <source>Do you want to save any changes before overwriting this file?</source>
        <translation>Wilt u de wijzigingen nog opslaan alvorens dit bestand te overschrijven?</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../Preferences.ui" line="14"/>
        <source>Preferences</source>
        <translation>Voorkeuren</translation>
    </message>
    <message>
        <location filename="../Preferences.cpp" line="90"/>
        <source>PageEdit</source>
        <translation>PageEdit</translation>
    </message>
    <message>
        <location filename="../Preferences.cpp" line="90"/>
        <source>Changes will take effect when you restart PageEdit.</source>
        <translation>Wijzigingen treden in werking als u PageEdit opnieuw start.</translation>
    </message>
    <message>
        <location filename="../Preferences.cpp" line="152"/>
        <source>Open Preferences Location</source>
        <translation>Map met voorkeuren openen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../OPFReader.cpp" line="59"/>
        <source>Unable to read OPF file.
Line: %1 Column %2 - %3</source>
        <translation>Kan OPF-bestand niet lezen.
Regel: %1 Kolom %2 - %3</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="379"/>
        <source>Cannot read file %1:
%2.</source>
        <translation>Kan bestand niet lezen: %1
%2.</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="560"/>
        <source>PageEdit has encountered a problem.</source>
        <translation>PageEdit is op een probleem gestuit.</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="561"/>
        <source>PageEdit may need to close.</source>
        <translation>PageEdit moet mogelijk afsluiten.</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="863"/>
        <source>About PageEdit</source>
        <translation>Over PageEdit</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="868"/>
        <source>Version</source>
        <translation>Versie</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="869"/>
        <source>Build Date</source>
        <translation>Datum bouw</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="870"/>
        <source>Build Time</source>
        <translation>Tijdstip bouw</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="871"/>
        <source>Qt Runtime Version</source>
        <translation>Qt runtime-versie</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="872"/>
        <source>Qt Compiled Version</source>
        <translation>Qt gecompileerde versie</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="873"/>
        <source>System</source>
        <translation>Systeem</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="874"/>
        <source>Architecture</source>
        <translation>Architectuur</translation>
    </message>
</context>
<context>
    <name>SearchToolbar</name>
    <message>
        <location filename="../SearchToolbar.ui" line="36"/>
        <source>Search: </source>
        <translation>Zoeken:</translation>
    </message>
    <message>
        <location filename="../SearchToolbar.ui" line="55"/>
        <source>Search...</source>
        <translation>Zoeken...</translation>
    </message>
    <message>
        <location filename="../SearchToolbar.ui" line="88"/>
        <source>&amp;Match Case</source>
        <translation>&amp;Hoofdlettergevoelig</translation>
    </message>
    <message>
        <location filename="../SearchToolbar.cpp" line="137"/>
        <source>No results found.</source>
        <translation>Geen resultaten gevonden.</translation>
    </message>
</context>
<context>
    <name>SelectCharacter</name>
    <message>
        <location filename="../SelectCharacter.ui" line="14"/>
        <source>Insert Special Character</source>
        <translation>Speciaal teken invoegen</translation>
    </message>
</context>
<context>
    <name>SelectFiles</name>
    <message>
        <location filename="../SelectFiles.ui" line="14"/>
        <source>Insert File</source>
        <translation>Bestand invoegen</translation>
    </message>
    <message>
        <location filename="../SelectFiles.ui" line="46"/>
        <source>List only the file names which contain the text you enter.</source>
        <translation>Alleen de bestandsnamen tonen die de tekst bevatten die u opgeeft.</translation>
    </message>
    <message>
        <location filename="../SelectFiles.ui" line="49"/>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <location filename="../SelectFiles.ui" line="118"/>
        <source>Thumbnail size:</source>
        <translation>Miniatuurgrootte</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="113"/>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="114"/>
        <source>Images</source>
        <translation>Afbeeldingen</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="115"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="116"/>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="159"/>
        <source>Media Files In the Book</source>
        <translation>Mediabestanden in het boek</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="162"/>
        <source>Thumbnails</source>
        <translation>Miniaturen</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="325"/>
        <source>shades</source>
        <translation>tinten</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="325"/>
        <source>colors</source>
        <translation>kleuren</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="326"/>
        <source>Grayscale</source>
        <translation>Grijstinten</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="326"/>
        <source>Color</source>
        <translation>Kleur</translation>
    </message>
</context>
<context>
    <name>SelectHyperlink</name>
    <message>
        <location filename="../SelectHyperlink.ui" line="14"/>
        <source>Select Target</source>
        <translation>Bestemming selecteren</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.ui" line="22"/>
        <source>List only the entries that match the text you enter.</source>
        <translation>Alleen de hyperlinks tonen die overeenkomen met de tekst die u opgeeft.</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.ui" line="25"/>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.ui" line="58"/>
        <source>Enter the target URL for this hyperlink.  You can select or 
double click on existing destinations in your book from the list above.</source>
        <translation>Geef de URL op voor de bestemming van deze hyperlink.  Vanuit bovenstaande lijst kunt u bestaande bestemmingen selecteren of erop dubbelklikken.</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.ui" line="62"/>
        <source>Target:</source>
        <translation>Bestemming:</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.cpp" line="94"/>
        <source>Targets in the Book</source>
        <translation>Bestemmingen in het boek</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.cpp" line="95"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
</context>
<context>
    <name>SelectId</name>
    <message>
        <location filename="../SelectId.ui" line="14"/>
        <source>Insert ID </source>
        <translation>Referentie invoegen</translation>
    </message>
    <message>
        <location filename="../SelectId.ui" line="22"/>
        <source>Enter an ID name to use as a destination for hyperlinks, notes, and TOC entries.

The dropdown box shows existing ID names in the current file.

ID names must be unique and start with a letter.</source>
        <translation>Een referentie opgeven om te gebruiken als bestemming voor hyperlinks, noten en vermeldingen op de inhoudsopgave.

De vervolgkeuzelijst toont referenties in het huidige bestand.

Referenties moeten uniek zijn en beginnen met een letter.</translation>
    </message>
    <message>
        <location filename="../SelectId.ui" line="29"/>
        <source>ID:</source>
        <translation>Referentie:</translation>
    </message>
</context>
<context>
    <name>Utility</name>
    <message>
        <location filename="../Utility.cpp" line="656"/>
        <source>PageEdit</source>
        <translation>PageEdit</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="657"/>
        <source>The requested file name contains non-ASCII characters. You should only use ASCII characters in filenames. Using non-ASCII characters can prevent the EPUB from working with some readers.

Continue using the requested filename?</source>
        <translation>De gevraagde bestandsnaam bevat niet-ASCII-tekens. U kunt beter bestandsnamen gebruiken met alleen ASCII-tekens. Het gebruiken van niet-ASCII-tekens kan ertoe leiden dat de EPUB op sommige e-readers niet werkt.

Wilt u de gevraagde bestandsnaam toch gebruiken?</translation>
    </message>
</context>
<context>
    <name>WebViewEdit</name>
    <message>
        <location filename="../WebViewEdit.cpp" line="167"/>
        <source>No suggestions</source>
        <translation>Geen suggesties</translation>
    </message>
    <message>
        <location filename="../WebViewEdit.cpp" line="179"/>
        <source>Check Spelling</source>
        <translation>Spelling controleren</translation>
    </message>
    <message>
        <location filename="../WebViewEdit.cpp" line="188"/>
        <source>Select Language</source>
        <translation>Taal selecteren</translation>
    </message>
</context>
</TS>